<?php
/**
 * Safha One Page: Customizer
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function safha_one_page_customize_register( $wp_customize ) {

	$wp_customize->add_panel( 'safha_one_page_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'safha-one-page' ),
	    'description' => __( 'Description of what this panel does.', 'safha-one-page' ),
	) );

	$wp_customize->add_section( 'safha_one_page_general_option', array(
    	'title'      => __( 'Sidebar Settings', 'safha-one-page' ),
		'priority'   => 30,
		'panel' => 'safha_one_page_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('safha_one_page_layout_settings',array(
        'default' => __('Right Sidebar','safha-one-page'),
        'sanitize_callback' => 'safha_one_page_sanitize_choices'	        
	));

	$wp_customize->add_control('safha_one_page_layout_settings',array(
        'type' => 'radio',
        'label'     => __('Theme Sidebar Layouts', 'safha-one-page'),
        'description'   => __('This option work for blog page, blog single page, archive page and search page.', 'safha-one-page'),
        'section' => 'safha_one_page_general_option',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','safha-one-page'),
            'Right Sidebar' => __('Right Sidebar','safha-one-page'),
            'One Column' => __('Full Width','safha-one-page'),
            'Grid Layout' => __('Grid Layout','safha-one-page')
        ),
	));

	//Topbar section
	$wp_customize->add_section('safha_one_page_contact_details',array(
		'title'	=> __('Topbar Section','safha-one-page'),
		'description'	=> __('Add Header Content here','safha-one-page'),
		'priority'	=> null,
		'panel' => 'safha_one_page_panel_id',
	));

	$wp_customize->add_setting('safha_one_page_email_address',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('safha_one_page_email_address',array(
		'label'	=> __('Add Email','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_email_address',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('safha_one_page_time',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('safha_one_page_time',array(
		'label'	=> __('Add Time','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_time',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('safha_one_page_contact_number',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('safha_one_page_contact_number',array(
		'label'	=> __('Add Phone Number','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_contact_number',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('safha_one_page_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('safha_one_page_facebook_url',array(
		'label'	=> __('Add Facebook link','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_facebook_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('safha_one_page_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('safha_one_page_twitter_url',array(
		'label'	=> __('Add Twitter link','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_twitter_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('safha_one_page_youtube_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('safha_one_page_youtube_url',array(
		'label'	=> __('Add Youtube link','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_youtube_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('safha_one_page_googleplus_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('safha_one_page_googleplus_url',array(
		'label'	=> __('Add Google Plus link','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_googleplus_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('safha_one_page_linkedin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('safha_one_page_linkedin_url',array(
		'label'	=> __('Add Linkedin link','safha-one-page'),
		'section'	=> 'safha_one_page_contact_details',
		'setting'	=> 'safha_one_page_linkedin_url',
		'type'	=> 'url'
	));

	//home page slider
	$wp_customize->add_section( 'safha_one_page_slider' , array(
    	'title'      => __( 'Slider Settings', 'safha-one-page' ),
		'priority'   => null,
		'panel' => 'safha_one_page_panel_id'
	) );

	$wp_customize->add_setting('safha_one_page_slider_arrows',array(
        'default' => 'true',
        'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('safha_one_page_slider_arrows',array(
     	'type' => 'checkbox',
      	'label' => __('Show / Hide slider','safha-one-page'),
      	'section' => 'safha_one_page_slider',
	));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'safha_one_page_slide_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'safha_one_page_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'safha_one_page_slide_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'safha-one-page' ),
			'section'  => 'safha_one_page_slider',
			'type'     => 'dropdown-pages'
		) );
	}

	//Our Features
	$wp_customize->add_section('safha_one_page_features',array(
		'title'	=> __('Our Features Section','safha-one-page'),
		'description'	=> __('Add Our Features sections below.','safha-one-page'),
		'panel' => 'safha_one_page_panel_id',
	));

	$wp_customize->add_setting('safha_one_page_features_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('safha_one_page_features_title',array(
		'label'	=> __('Section Title','safha-one-page'),
		'section'	=> 'safha_one_page_features',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('safha_one_page_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('safha_one_page_text',array(
		'label'	=> __('Add Text','safha-one-page'),
		'section'	=> 'safha_one_page_features',
		'type'		=> 'text'
	));

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('safha_one_page_features_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('safha_one_page_features_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','safha-one-page'),
		'section' => 'safha_one_page_features',
	));

	//Footer
	$wp_customize->add_section( 'safha_one_page_footer' , array(
    	'title'      => __( 'Footer Text', 'safha-one-page' ),
		'priority'   => null,
		'panel' => 'safha_one_page_panel_id'
	) );

	$wp_customize->add_setting('safha_one_page_footer_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('safha_one_page_footer_text',array(
		'label'	=> __('Add Copyright Text','safha-one-page'),
		'section'	=> 'safha_one_page_footer',
		'setting'	=> 'safha_one_page_footer_text',
		'type'		=> 'text'
	));


	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'safha_one_page_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'safha_one_page_customize_partial_blogdescription',
	) );
	
}
add_action( 'customize_register', 'safha_one_page_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Safha One Page 1.0
 * @see safha-one-page_customize_register()
 *
 * @return void
 */
function safha_one_page_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Safha One Page 1.0
 * @see safha-one-page_customize_register()
 *
 * @return void
 */
function safha_one_page_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Return whether we're on a view that supports a one or two column layout.
 */
function safha_one_page_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'footer-1' ) ) );
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Safha_One_Page_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Safha_One_Page_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Safha_One_Page_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Safha One Page Pro', 'safha-one-page' ),
					'pro_text' => esc_html__( 'Go Pro', 'safha-one-page' ),
					'pro_url'  => esc_url('https://www.themeseye.com/wordpress/one-page-wordpress-theme/'),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'safha-one-page-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'safha-one-page-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Safha_One_Page_Customize::get_instance();